# persian-names

A simple Python library for generating random Persian (Farsi) names.

# Installation

`pip install persian-names`

# Usage

Let's take a look at what an example test case would look like using `persian-names`.


To generate a Persian name in English:

```python
import persian_names as pn

pn.fullname_en('male')
pn.fullname_en('female')
pn.fullname_en('random')
```

To generate a Persian name in Farsi:

```python
import persian_names as pn

pn.fullname_fa('male')
pn.fullname_fa('female')
pn.fullname_fa('random')
```
